﻿using System.Windows;
using System.Windows.Controls;

namespace LOTO
{
    public partial class MainWindow : Window
    {

        //new operator von Lotto class
        private Lotto lotto = new Lotto();

        private List<int[]> tickets = new List<int[]>();
        private int ticketsZahl = 0;
        private int aktuellesTicketIndex = 0;

        public MainWindow()
        {
            InitializeComponent();

            // Wenn dieses Optionsfeld angeklickt ist, wird diese Methode ausgeführt

            rbMixed.Checked += RbMixed_Checked;
            rbAllesRandom.Checked += RbAllesRandom_Checked;
            rbManuell.Checked += RbManuell_Checked;
            rbTicketRandom.Checked += RbTicketRandom_Checked;
        }

        private void RbMixed_Checked(object sender, RoutedEventArgs e)
        {
            // Mixed mode wird in SpielStarten behandelt 
        }

        private void RbAllesRandom_Checked(object sender, RoutedEventArgs e)
        {
            //Das  Panel wird ausgeblendet,wenn allesrandom radio button ausgewählt wird.

            ManuellPanelInput.Visibility = Visibility.Collapsed;
        }

        private void RbManuell_Checked(object sender, RoutedEventArgs e)
        {
            //macht ZahlPanel sichbar ,wenn Manuell radio button ausgewählt wird

            ZahlPanelInput.Visibility = Visibility.Visible;
        }

        private void RbTicketRandom_Checked(object sender, RoutedEventArgs e)
        {
            //macht den Panel von Zahlen unsihtbar,wenn radio button von Ticket random ausgeqählt wird.

            ZahlPanelInput.Visibility = Visibility.Collapsed;
        }

        //Event Handler von Button der Spiel Starten
        private void BtnSpielStarten(object sender, RoutedEventArgs e)
        {
            ticketsZahl = Convert.ToInt32(txtTicketCount.Text);


            if (ticketsZahl <= 0)
            {

                MessageBox.Show("Bitte geben Sie eine gültige Ticketanzahl ein.", "Ungültige Eingabe", MessageBoxButton.OK, MessageBoxImage.Warning);
                return;

            }

            aktuellesTicketIndex = 0;

            btnSpielStarten.IsEnabled = false;

            if (rbAllesRandom.IsChecked == true)
            {
                // All random tickets
                for (int i = 0; i < ticketsZahl; i++)
                {
                    tickets.Add(lotto.RandomNumbers());
                }
                Process();
            }
            else
            {
                // Mixed mode 
                ShowTicketInput();
            }
        }

        private void ShowTicketInput()
        {
            if (aktuellesTicketIndex < ticketsZahl)
            {
                ManuellPanelInput.Visibility = Visibility.Visible;
                aktuellesLabelticket.Content = $"Ticket {aktuellesTicketIndex + 1} von {ticketsZahl}";

                // Vorherige Eingaben löschen

                txt1.Text = txt2.Text = txt3.Text = txt4.Text = txt5.Text = txt6.Text = "";

            }
            else
            {
                //wenn alle Tickets gefüllt werden,start prozessing und macht den Panel von Inputs unsichtbar.
                ManuellPanelInput.Visibility = Visibility.Collapsed;
                Process();
            }
        }

        private void BtnBestätigen(object sender, RoutedEventArgs e)
        {
            if (rbTicketRandom.IsChecked == true)
            {
                // Random ticket
                tickets.Add(lotto.RandomNumbers());
            }
            else
            {
                // Manual ticket
                int[] numbers = new int[6];
                TextBox[] textBoxes = { txt1, txt2, txt3, txt4, txt5, txt6 };

                // Prüft jeder gegebene zahl
                for (int i = 0; i < 6; i++)
                {
                    int number = Convert.ToInt32(textBoxes[i].Text);

                    // Validation
                    if (number < 1 || number > 49)
                    {
                        MessageBox.Show($"Bitte geben Sie eine gültige Nummer (1-49) für die Position {i + 1} ein.", "Ungültige Eingabe", MessageBoxButton.OK, MessageBoxImage.Warning);
                        return;
                    }

                    // Prüft Duplikation
                    if (lotto.DuplicateChecker(numbers, number))
                    {
                        MessageBox.Show("Bitte geben Sie 6 verschiedene Zahlen ein.", "Doppelte Nummern", MessageBoxButton.OK, MessageBoxImage.Warning);
                        return;
                    }

                    // Addiert Zahl zu Array
                    numbers[i] = number;
                }

                // Gültig Array wird in die List hinzugefügt
                tickets.Add(numbers);
            }

            // Index wird aktualisiert
            aktuellesTicketIndex++;
            // Ruft die Method wieder auf,um ein anderes Panel zu erzeugen.
            ShowTicketInput();
        }

        //Hiere verwenden wir result als ein container,der alles text ,die wird erzeugt und zeigt speichert.
        private void Process()
        {
            ManuellPanelInput.Visibility = Visibility.Collapsed;

            // erzeugen GewinnZahlen

            int[] winZahlen = lotto.RandomNumbers();

            // Ergebnise zeigen

            string result = "";
            result += "The winning numbers are: " + string.Join(", ", winZahlen) + "\n\n";

            // Alle tickets zeigen

            for (int i = 0; i < tickets.Count; i++)
            {
                result += $"Ticket {i + 1}: " + string.Join(", ", tickets[i]) + "\n";
            }
            result += "\n";

            // vergleichen und die ergebnisse zeigen

            for (int i = 0; i < tickets.Count; i++)
            {
                result += VergleichTicket(tickets[i], winZahlen, i + 1) + "\n";
            }

            // Wahrscheinlichkeit zeigen

            result += "\n" + GetStatistics() + "\n";
            result += $"Die Warscheinlichkeit von {ticketsZahl} tickets its: {lotto.Möglichkeit(ticketsZahl):F10}\n";

            txtErgebnisse.Text = result;
        }

        //vergleichen wir jeder Ticket mit dem Gewinnarray
        private string VergleichTicket(int[] userNumbers, int[] winNumbers, int ticketNumber)
        {
            //array sortieren ,um recursiv binary search zu verwenden.

            Array.Sort(winNumbers);
            int count = 0;
            string result = "";

            for (int i = 0; i < 6; i++)
            {
                //count von Matches steigt,wenn die Method true gibt aus.

                if (lotto.RevursivBinarySearch(winNumbers, userNumbers[i], 0, winNumbers.Length - 1))
                {
                    count++;
                }
            }

            //wenn ein Ticket hat 6 matches ,dass heißt,dass der Spieler gewonnen hat.

            if (count == 6)
            {
                result = "**************************************************\n";
                result += "You are a winner sir, sie haben 6 matches\n";
                result += $"Sie Haben mit Ticket {ticketNumber} gewonnen\n";
                result += "**************************************************";
            }
            else
            {
                //zeigt ,wie viel matches die Ticket hat.
                result = $"Ticket {ticketNumber} hat {count} matches\n";
            }

            lotto.Stats(count);
            return result;
        }

        private string GetStatistics()
        {
            string stats = "";

            //Ruft Stats Method auf ,um die MathchCounts zu bekommen.(Stats(0) ruft Daten ab, ohne die Zähler zu erhöhen),
            int[] matchCounts = lotto.Stats(0);

            for (int i = 0; i < 7; i++)
            {
                if (matchCounts[i] > 0)
                {
                    stats += $"Es Gibt {matchCounts[i]} tickets ,die {i} matches haben \n";
                }
            }
            return stats;
        }

        
    }

}